@@ -132,6 +132,8 @@ void Buffer::setLangType(LangType lang, const wchar_t* userLangName)
 	_lang = lang;
 	if (_lang == L_USER)
 		_userLangExt = userLangName;
+	else if (_lang == L_ASCII)
+		_encoding = NPP_CP_DOS_437;
 
 	_needLexer = true;	//change of lang means lexern needs updating
 	doNotify(BufferChangeLanguage | BufferChangeLexing);
@@ -729,7 +731,7 @@ BufferID FileManager::loadFile(const wchar_t* filename, Document doc, int encodi
 	if (fileSize == -1)
 	{
 		// we cannot continue (or Scintilla will throw SC_STATUS_FAILURE in the loadFileData later)
-		::MessageBox(_pNotepadPlus->_pEditView->getHSelf(), L"Cannot obtain the file size before loading!", L"File to load size-check failed", MB_OK | MB_APPLMODAL);
+		// - no error message here as this can be also a dir with files to open or globbing attempt
 		return BUFFER_INVALID;
 	}
 
@@ -815,18 +817,20 @@ BufferID FileManager::loadFile(const wchar_t* filename, Document doc, int encodi
 		if (res != 0) // res == 1 or res == -1
 			newBuf->_timeStamp = fileNameTimestamp;
 
-		_buffers.push_back(newBuf);
-		++_nbBufs;
-		Buffer* buf = _buffers.at(_nbBufs - 1);
-
 		// restore the encoding (ANSI based) while opening the existing file
-		buf->setEncoding(-1);
+		if (newBuf->_lang == L_ASCII)
+			newBuf->setEncoding(NPP_CP_DOS_437);
+		else
+			newBuf->setEncoding(-1);
 
 		// if not a large file, no file extension, and the language has been detected,  we use the detected value
-		if (!newBuf->_isLargeFile && ((buf->getLangType() == L_TEXT) && (loadedFileFormat._language != L_TEXT)))
-			buf->setLangType(loadedFileFormat._language);
+		if (!newBuf->_isLargeFile && ((newBuf->getLangType() == L_TEXT) && (loadedFileFormat._language != L_TEXT)))
+			newBuf->setLangType(loadedFileFormat._language);
 
-		setLoadedBufferEncodingAndEol(buf, UnicodeConvertor, loadedFileFormat._encoding, loadedFileFormat._eolFormat);
+		setLoadedBufferEncodingAndEol(newBuf, UnicodeConvertor, loadedFileFormat._encoding, loadedFileFormat._eolFormat);
+
+		_buffers.push_back(newBuf);
+		++_nbBufs;
 
 		//determine buffer properties
 		++_nextBufferID;
