@@ -42,7 +42,7 @@ public :
 	void addIcon(int iconID, int cx = 16, int cy = 16, int failIconID = -1) const;
 	void addIcon(HICON hIcon) const;
 
-	bool changeIcon(size_t index, const TCHAR *iconLocation) const;
+	bool changeIcon(size_t index, const wchar_t *iconLocation) const;
 
 private :
 	HIMAGELIST _hImglst = nullptr;
@@ -142,7 +142,7 @@ public :
 		return _tbiis[i]._stdIcon;
 	};
 
-	bool replaceIcon(size_t witchList, size_t iconIndex, const TCHAR *iconLocation) const {
+	bool replaceIcon(size_t witchList, size_t iconIndex, const wchar_t *iconLocation) const {
 		if ((witchList != HLIST_DEFAULT) && (witchList != HLIST_DISABLE) && 
 			(witchList != HLIST_DEFAULT2) && (witchList != HLIST_DISABLE2) &&
 			(witchList != HLIST_DEFAULT_DM) && (witchList != HLIST_DISABLE_DM) && 
