@@ -47,10 +47,11 @@
     #define    IDM_FILE_OPEN_DEFAULT_VIEWER              (IDM_FILE + 23)
     #define    IDM_FILE_CLOSEALL_UNCHANGED               (IDM_FILE + 24)
     #define    IDM_FILE_CONTAININGFOLDERASWORKSPACE      (IDM_FILE + 25)
+    #define    IDM_FILE_CLOSEALL_BUT_PINNED              (IDM_FILE + 26)
 // IMPORTANT: If list above is modified, you have to change the following values:
  
 // To be updated if new menu item(s) is (are) added in menu "File"
-    #define    IDM_FILEMENU_LASTONE             IDM_FILE_CONTAININGFOLDERASWORKSPACE
+    #define    IDM_FILEMENU_LASTONE             IDM_FILE_CLOSEALL_BUT_PINNED
 
 // 0 based position of command "Exit" including the bars in the file menu
 // and without counting "Recent files history" items
@@ -320,7 +321,7 @@
     //#define    IDM_VIEW_DOCCHANGEMARGIN           (IDM_VIEW + 45)
     //#define    IDM_VIEW_LWDEF                     (IDM_VIEW + 46)
     //#define    IDM_VIEW_LWALIGN                   (IDM_VIEW + 47)
-    //#define    IDM_VIEW_LWINDENT                  (IDM_VIEW + 48)
+    #define    IDM_PINTAB                         (IDM_VIEW + 48)
     #define    IDM_VIEW_SUMMARY                   (IDM_VIEW + 49)
 
     #define    IDM_VIEW_FOLD                      (IDM_VIEW + 50)
