@@ -19,14 +19,14 @@
 //
 // Notepad++ version: begin
 //
-#define NOTEPAD_PLUS_VERSION L"Notepad++ v8.7.2"
+#define NOTEPAD_PLUS_VERSION L"Notepad++ v8.7.4"
 
 // should be X.Y : ie. if VERSION_DIGITALVALUE == 4, 7, 1, 0 , then X = 4, Y = 71
 // ex : #define VERSION_VALUE L"5.63\0"
-#define VERSION_INTERNAL_VALUE L"8.72\0"
+#define VERSION_INTERNAL_VALUE L"8.74\0"
 
-#define VERSION_PRODUCT_VALUE L"8.7.2\0"
-#define VERSION_DIGITALVALUE 8, 7, 2, 0
+#define VERSION_PRODUCT_VALUE L"8.7.4\0"
+#define VERSION_DIGITALVALUE 8, 7, 4, 0
 
 // Notepad++ version: end
 
@@ -714,7 +714,7 @@
 	#define NPPM_INTERNAL_DOCMODIFIEDBYREPLACEALL       (NOTEPADPLUS_USER_INTERNAL + 79)
 	#define NPPM_INTERNAL_DRAWTABBARPINBUTTON           (NOTEPADPLUS_USER_INTERNAL + 80)
 	#define NPPM_INTERNAL_DRAWTABBARCLOSEBUTTON         (NOTEPADPLUS_USER_INTERNAL + 81)
-	#define NPPM_INTERNAL_REFRESHTABAR                  (NOTEPADPLUS_USER_INTERNAL + 82)
+	//#define NPPM_INTERNAL_REFRESHTABAR                  (NOTEPADPLUS_USER_INTERNAL + 82)
 	#define NPPM_INTERNAL_REDUCETABBAR                  (NOTEPADPLUS_USER_INTERNAL + 83)
 	#define NPPM_INTERNAL_LOCKTABBAR                    (NOTEPADPLUS_USER_INTERNAL + 84)
 	#define NPPM_INTERNAL_DRAWINACIVETAB                (NOTEPADPLUS_USER_INTERNAL + 85)
